@@ -18,7 +18,6 @@ import fractions
 
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 from stevedore import driver
 from voluptuous import All
 from voluptuous import Any
@@ -90,10 +89,11 @@ METRIC_BASE_SCHEMA = {
     Required('metadata', default=list): [
         All(str, Length(min=1))
     ],
-    # Mutate collected value. May be any of (NONE, NUMBOOL, FLOOR, CEIL).
+    # Mutate collected value. May be any of:
+    # (NONE, NUMBOOL, NOTNUMBOOL, FLOOR, CEIL).
     # Defaults to NONE
     Required('mutate', default='NONE'):
-        In(['NONE', 'NUMBOOL', 'FLOOR', 'CEIL']),
+        In(['NONE', 'NUMBOOL', 'NOTNUMBOOL', 'FLOOR', 'CEIL']),
     # Collector-specific args. Should be overriden by schema provided for
     # the given collector
     Optional('extra_args'): dict,
@@ -153,8 +153,7 @@ class NoDataCollected(Exception):
         self.resource = resource
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseCollector(object):
+class BaseCollector(object, metaclass=abc.ABCMeta):
     collector_name = None
 
     def __init__(self, **kwargs):
