@@ -19,6 +19,7 @@ from decimal import ROUND_HALF_UP
 from oslo_config import cfg
 from oslo_log import log
 from voluptuous import In
+from voluptuous import Optional
 from voluptuous import Required
 from voluptuous import Schema
 
@@ -27,8 +28,8 @@ from cloudkitty.collector.exceptions import CollectError
 from cloudkitty.common.prometheus_client import PrometheusClient
 from cloudkitty.common.prometheus_client import PrometheusResponseError
 from cloudkitty import dataframe
-from cloudkitty import tzutils
 from cloudkitty import utils as ck_utils
+from cloudkitty.utils import tz as tzutils
 
 
 LOG = log.getLogger(__name__)
@@ -71,6 +72,18 @@ PROMETHEUS_EXTRA_SCHEMA = {
                 'min', 'stddev', 'stdvar',
                 'sum'
             ]),
+        Optional('query_function'):
+            In([
+                'abs', 'ceil', 'exp',
+                'floor', 'ln', 'log2',
+                'log10', 'round', 'sqrt'
+            ]),
+        Optional('range_function'):
+            In([
+                'changes', 'delta', 'deriv',
+                'idelta', 'irange', 'irate',
+                'rate'
+            ])
     }
 }
 
@@ -117,7 +130,7 @@ class PrometheusCollector(collector.BaseCollector):
         """
         metadata = {}
         for meta in self.conf[metric_name]['metadata']:
-            metadata[meta] = data['metric'][meta]
+            metadata[meta] = data['metric'].get(meta, '')
 
         groupby = {scope_key: scope_id}
         for meta in self.conf[metric_name]['groupby']:
@@ -132,6 +145,7 @@ class PrometheusCollector(collector.BaseCollector):
                 self.conf[metric_name]['factor'],
                 self.conf[metric_name]['offset'],
             )
+            qty = ck_utils.mutate(qty, self.conf[metric_name]['mutate'])
 
         return metadata, groupby, qty
 
@@ -139,18 +153,49 @@ class PrometheusCollector(collector.BaseCollector):
         """Returns metrics to be valorized."""
         scope_key = CONF.collect.scope_key
         method = self.conf[metric_name]['extra_args']['aggregation_method']
+        query_function = self.conf[metric_name]['extra_args'].get(
+            'query_function')
+        range_function = self.conf[metric_name]['extra_args'].get(
+            'range_function')
         groupby = self.conf[metric_name].get('groupby', [])
         metadata = self.conf[metric_name].get('metadata', [])
         period = tzutils.diff_seconds(end, start)
         time = end
 
-        query = '{0}({0}_over_time({1}{{{2}="{3}"}}[{4}s])) by ({5})'.format(
-            method,
+        # The metric with the period
+        query = '{0}{{{1}="{2}"}}[{3}s]'.format(
             metric_name,
             scope_key,
             scope_id,
-            period,
-            ', '.join(groupby + metadata),
+            period
+        )
+        # Applying the aggregation_method or the range_function on
+        # a Range Vector
+        if range_function is not None:
+            query = "{0}({1})".format(
+                range_function,
+                query
+            )
+        else:
+            query = "{0}_over_time({1})".format(
+                method,
+                query
+            )
+        # Applying the query_function
+        if query_function is not None:
+            query = "{0}({1})".format(
+                query_function,
+                query
+            )
+        # Applying the aggregation_method on a Instant Vector
+        query = "{0}({1})".format(
+            method,
+            query
+        )
+        # Filter by groupby and metadata
+        query = "{0} by ({1})".format(
+            query,
+            ', '.join(groupby + metadata)
         )
 
         try:
