@@ -230,13 +230,13 @@ class HashMapMapping(Base, HashMapBase):
         sqlalchemy.String(255),
         nullable=True)
     cost = sqlalchemy.Column(
-        sqlalchemy.Numeric(20, 8),
+        sqlalchemy.Numeric(30, 28),
         nullable=False)
     map_type = sqlalchemy.Column(
         sqlalchemy.Enum(
             'flat',
             'rate',
-            name='enum_map_type'),
+            name='enum_map_type', create_constraint=True),
         nullable=False)
     service_id = sqlalchemy.Column(
         sqlalchemy.Integer,
@@ -309,13 +309,13 @@ class HashMapThreshold(Base, HashMapBase):
         sqlalchemy.Numeric(20, 8),
         nullable=True)
     cost = sqlalchemy.Column(
-        sqlalchemy.Numeric(20, 8),
+        sqlalchemy.Numeric(30, 28),
         nullable=False)
     map_type = sqlalchemy.Column(
         sqlalchemy.Enum(
             'flat',
             'rate',
-            name='enum_hashmap_type'),
+            name='enum_hashmap_type', create_constraint=True),
         nullable=False)
     service_id = sqlalchemy.Column(
         sqlalchemy.Integer,
