@@ -241,7 +241,7 @@ class ElasticsearchClient(object):
         :param instruction: instruction to execute for each term
         :type instruction: dict
         :param terms: list of terms for which instruction should be executed
-        :type terms: collections.Iterable
+        :type terms: collections.abc.Iterable
         :rtype: requests.models.Response
         """
         instruction = json.dumps(instruction)
@@ -256,7 +256,7 @@ class ElasticsearchClient(object):
         """Indexes each of the documents in 'terms'
 
         :param terms: list of documents to index
-        :type terms: collections.Iterable
+        :type terms: collections.abc.Iterable
         """
         LOG.debug("Indexing {} documents".format(len(terms)))
         return self.bulk_with_instruction({"index": {}}, terms)
@@ -349,7 +349,12 @@ class ElasticsearchClient(object):
         return self._req(self._sess.post, url, data, None)
 
     def total(self, begin, end, metric_types, filters, groupby,
-              offset=0, limit=1000, paginate=True):
+              custom_fields=None, offset=0, limit=1000, paginate=True):
+
+        if custom_fields:
+            LOG.warning("'custom_fields' are not implemented yet for "
+                        "ElasticSearch. Therefore, the custom fields [%s] "
+                        "informed by the user will be ignored.", custom_fields)
         if not paginate:
             offset = 0
 
