@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Stéphane Albert
-#
 import copy
 
 from oslo_config import cfg
@@ -103,10 +101,10 @@ class WriteOrchestrator(object):
         if not timeframe_end:
             timeframe_end = timeframe + self._period
         try:
-            group_filters = {'project_id': self._tenant_id}
+            filters = {'project_id': self._tenant_id}
             data = self._storage.retrieve(begin=timeframe,
                                           end=timeframe_end,
-                                          group_filters=group_filters,
+                                          filters=filters,
                                           paginate=False)
             for df in data['dataframes']:
                 for service, resources in df['usage'].items():
